@@ -2,8 +2,9 @@ use 5.14.0;
 
 package Map::Metro::Plugin::Map::Budapest;
 
-our $VERSION = '0.1001'; # VERSION
 # ABSTRACT: Map::Metro map for Budapest
+our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
+our $VERSION = '0.1002';
 
 use Moose;
 with 'Map::Metro::Plugin::Map';
@@ -29,22 +30,21 @@ Map::Metro::Plugin::Map::Budapest - Map::Metro map for Budapest
 
 
 
-=begin HTML
+=begin html
 
-<p><img src="https://img.shields.io/badge/perl-5.16+-brightgreen.svg" alt="Requires Perl 5.16+" /> <a href="https://travis-ci.org/Csson/p5-Map-Metro-Budapest"><img src="https://api.travis-ci.org/Csson/p5-Map-Metro-Budapest.svg?branch=master" alt="Travis status" /></a></p>
+<p>
+<img src="https://img.shields.io/badge/perl-5.16+-blue.svg" alt="Requires Perl 5.16+" />
+<a href="https://travis-ci.org/Csson/p5-Map-Metro-Budapest"><img src="https://api.travis-ci.org/Csson/p5-Map-Metro-Budapest.svg?branch=master" alt="Travis status" /></a>
+<a href="http://cpants.cpanauthors.org/release/CSSON/Map-Metro-Plugin-Map-Budapest-0.1002"><img src="http://badgedepot.code301.com/badge/kwalitee/CSSON/Map-Metro-Plugin-Map-Budapest/0.1002" alt="Distribution kwalitee" /></a>
+<a href="http://matrix.cpantesters.org/?dist=Map-Metro-Plugin-Map-Budapest%200.1002"><img src="http://badgedepot.code301.com/badge/cpantesters/Map-Metro-Plugin-Map-Budapest/0.1002" alt="CPAN Testers result" /></a>
+<img src="https://img.shields.io/badge/coverage-90.0%-yellow.svg" alt="coverage 90.0%" />
+</p>
 
-=end HTML
-
-
-=begin markdown
-
-![Requires Perl 5.16+](https://img.shields.io/badge/perl-5.16+-brightgreen.svg) [![Travis status](https://api.travis-ci.org/Csson/p5-Map-Metro-Budapest.svg?branch=master)](https://travis-ci.org/Csson/p5-Map-Metro-Budapest)
-
-=end markdown
+=end html
 
 =head1 VERSION
 
-Version 0.1001, released 2015-03-23.
+Version 0.1002, released 2019-02-27.
 
 =head1 SYNOPSIS
 
@@ -89,7 +89,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson <info@code301.com>.
+This software is copyright (c) 2016 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
